@@ -111,8 +111,8 @@ int  xine_check_version (int major, int minor, int sub) XINE_PROTECTED;
 /* static info - which libxine release this header came from */
 #define XINE_MAJOR_VERSION 1
 #define XINE_MINOR_VERSION 1
-#define XINE_SUB_VERSION   14
-#define XINE_VERSION       "1.1.14"
+#define XINE_SUB_VERSION   18
+#define XINE_VERSION       "1.1.18.1"
 
 /*
  * pre-init the xine engine
@@ -983,13 +983,28 @@ const char *xine_get_meta_info   (xine_stream_t *stream, int info) XINE_PROTECTE
 #define XINE_META_INFO_ARTIST              2
 #define XINE_META_INFO_GENRE               3
 #define XINE_META_INFO_ALBUM               4
-#define XINE_META_INFO_YEAR                5
+#define XINE_META_INFO_YEAR                5 /* may be full date */
 #define XINE_META_INFO_VIDEOCODEC          6
 #define XINE_META_INFO_AUDIOCODEC          7
 #define XINE_META_INFO_SYSTEMLAYER         8
 #define XINE_META_INFO_INPUT_PLUGIN        9
 #define XINE_META_INFO_CDINDEX_DISCID      10
 #define XINE_META_INFO_TRACK_NUMBER        11
+#define XINE_META_INFO_COMPOSER            12
+/* post-1.1.17; taken from the list at http://age.hobba.nl/audio/mirroredpages/ogg-tagging.html on 2009-12-11 */
+#define XINE_META_INFO_PUBLISHER	   13
+#define XINE_META_INFO_COPYRIGHT	   14
+#define XINE_META_INFO_LICENSE		   15
+#define XINE_META_INFO_ARRANGER		   16
+#define XINE_META_INFO_LYRICIST		   17
+#define XINE_META_INFO_AUTHOR		   18
+#define XINE_META_INFO_CONDUCTOR	   19
+#define XINE_META_INFO_PERFORMER	   20
+#define XINE_META_INFO_ENSEMBLE		   21
+#define XINE_META_INFO_OPUS		   22
+#define XINE_META_INFO_PART		   23
+#define XINE_META_INFO_PARTNUMBER	   24
+#define XINE_META_INFO_LOCATION		   25
 
 
 /*********************************************************************
@@ -1785,6 +1800,7 @@ void xine_config_reset (xine_t *self) XINE_PROTECTED;
 #define XINE_EVENT_VDR_SELECTAUDIO      352
 #define XINE_EVENT_VDR_TRICKSPEEDMODE   353
 #define XINE_EVENT_VDR_PLUGINSTARTED    354
+#define XINE_EVENT_VDR_DISCONTINUITY    355
 
 /* events generated from post plugins */
 #define XINE_EVENT_POST_TVTIME_FILMMODE_CHANGE   400
@@ -1913,7 +1929,7 @@ typedef struct {
 typedef struct {
   int                 alternative; /* alternative playlist number, usually 0 */
   char                mrl[1]; /* might (will) be longer */
-} xine_mrl_reference_data_t;
+} xine_mrl_reference_data_t XINE_DEPRECATED;
 
 typedef struct {
   int                 alternative; /* as above */
